.. _session_module:

:mod:`cubicweb.pyramid.session`
-------------------------------

.. automodule:: cubicweb.pyramid.session

    .. autofunction:: includeme

    .. autofunction:: CWSessionFactory
